#
# DO NOT MODIFY!!!!
# This file is automatically generated by Racc 1.8.1
# from Racc grammar file "parser.y".
#

require 'racc/parser.rb'
module Tomlrb
  class GeneratedParser < Racc::Parser
##### State transition tables begin ###

racc_action_table = [
     2,    49,    16,    25,    17,    48,    18,    23,    24,    19,
    20,    14,    21,    22,     8,     4,    10,    60,    16,    12,
    17,    59,    18,    23,    24,    19,    20,    46,    21,    22,
    28,    51,    54,    53,    54,    84,    43,    77,    78,    79,
    80,    75,    76,    72,    73,    70,    71,    74,    93,    92,
    63,    40,    55,    12,    77,    78,    79,    80,    75,    76,
    72,    73,    70,    71,    74,    43,    58,    63,    87,    87,
    12,    77,    78,    79,    80,    75,    76,    72,    73,    70,
    71,    74,    54,   nil,    63,    98,   nil,    12,    77,    78,
    79,    80,    75,    76,    72,    73,    70,    71,    74,    87,
   nil,    63,   111,   nil,    12,    77,    78,    79,    80,    75,
    76,    72,    73,    70,    71,    74,    54,   nil,    63,    98,
   nil,    12,    77,    78,    79,    80,    75,    76,    72,    73,
    70,    71,    74,    54,   nil,    63,    98,   nil,    12,    77,
    78,    79,    80,    75,    76,    72,    73,    70,    71,    74,
    87,   nil,    63,   111,    31,    12,    32,   nil,    33,    38,
    39,    34,    35,    29,    36,    37,    16,   nil,    17,    28,
    18,    23,    24,    19,    20,    82,    21,    22,    31,   nil,
    32,   nil,    33,    38,    39,    34,    35,    86,    36,    37,
    16,   nil,    17,   nil,    18,    23,    24,    19,    20,    46,
    21,    22,    16,   nil,    17,   nil,    18,    23,    24,    19,
    20,    91,    21,    22,    54,    54,    87,    98,    98,   111,
   nil,   109,   109,   118 ]

racc_action_check = [
     1,    13,     1,     2,     1,    13,     1,     1,     1,     1,
     1,     1,     1,     1,     1,     1,     1,    45,    11,     1,
    11,    45,    11,    11,    11,    11,    11,    11,    11,    11,
    26,    26,    27,    27,    50,    50,    11,    48,    48,    48,
    48,    48,    48,    48,    48,    48,    48,    48,    61,    61,
    48,    10,    28,    48,    59,    59,    59,    59,    59,    59,
    59,    59,    59,    59,    59,    42,    44,    59,    52,    83,
    59,    62,    62,    62,    62,    62,    62,    62,    62,    62,
    62,    62,    62,   nil,    62,    62,   nil,    62,    96,    96,
    96,    96,    96,    96,    96,    96,    96,    96,    96,    96,
   nil,    96,    96,   nil,    96,   105,   105,   105,   105,   105,
   105,   105,   105,   105,   105,   105,   105,   nil,   105,   105,
   nil,   105,   112,   112,   112,   112,   112,   112,   112,   112,
   112,   112,   112,   112,   nil,   112,   112,   nil,   112,   116,
   116,   116,   116,   116,   116,   116,   116,   116,   116,   116,
   116,   nil,   116,   116,     9,   116,     9,   nil,     9,     9,
     9,     9,     9,     9,     9,     9,    49,   nil,    49,     9,
    49,    49,    49,    49,    49,    49,    49,    49,    51,   nil,
    51,   nil,    51,    51,    51,    51,    51,    51,    51,    51,
    58,   nil,    58,   nil,    58,    58,    58,    58,    58,    58,
    58,    58,    60,   nil,    60,   nil,    60,    60,    60,    60,
    60,    60,    60,    60,    94,   104,   108,    94,   104,   108,
   nil,    94,   104,   108 ]

racc_action_pointer = [
   nil,     0,     3,   nil,   nil,   nil,   nil,   nil,   nil,   152,
    35,    16,   nil,   -17,   nil,   nil,   nil,   nil,   nil,   nil,
   nil,   nil,   nil,   nil,   nil,   nil,    13,    18,    35,   nil,
   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,
   nil,   nil,    45,   nil,    45,    -1,   nil,   nil,    34,   164,
    20,   176,    54,   nil,   nil,   nil,   nil,   nil,   188,    51,
   200,    34,    68,   nil,   nil,   nil,   nil,   nil,   nil,   nil,
   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,
   nil,   nil,   nil,    55,   nil,   nil,   nil,   nil,   nil,   nil,
   nil,   nil,   nil,   nil,   200,   nil,    85,   nil,   nil,   nil,
   nil,   nil,   nil,   nil,   201,   102,   nil,   nil,   202,   nil,
   nil,   nil,   119,   nil,   nil,   nil,   136,   nil,   nil,   nil,
   nil ]

racc_action_default = [
    -1,   -97,   -97,    -2,    -3,    -4,    -5,    -6,    -7,   -97,
   -13,   -97,   -31,   -97,   -45,   -46,   -47,   -48,   -49,   -50,
   -51,   -52,   -53,   -54,   -55,   121,   -97,   -97,   -15,   -18,
   -19,   -20,   -21,   -22,   -23,   -24,   -25,   -26,   -27,   -28,
   -12,   -29,   -97,   -32,   -33,   -97,   -39,   -40,   -84,   -97,
   -97,   -97,   -10,   -11,   -73,   -14,   -30,   -34,   -97,   -84,
   -97,   -97,   -97,   -67,   -74,   -75,   -76,   -80,   -81,   -85,
   -86,   -87,   -88,   -89,   -90,   -91,   -92,   -93,   -94,   -95,
   -96,   -43,   -44,    -8,    -9,   -16,   -17,   -72,   -35,   -36,
   -37,   -38,   -41,   -42,   -97,   -60,   -97,   -62,   -69,   -77,
   -78,   -79,   -82,   -83,   -97,   -97,   -59,   -64,   -97,   -71,
   -61,   -68,   -97,   -57,   -63,   -58,   -97,   -66,   -70,   -56,
   -65 ]

racc_goto_table = [
    52,    15,    97,     7,    42,    95,    61,    41,    27,    65,
    30,    67,     1,    69,     3,     5,   105,    89,   107,     6,
    65,     9,    67,    83,    69,    50,   112,    26,   114,    57,
    13,    94,   104,   nil,   nil,    96,   110,   106,    56,   nil,
   nil,   nil,   nil,   nil,   nil,   nil,   nil,   113,   115,    81,
    66,    88,    85,   nil,   nil,   119,   120,   nil,   nil,   nil,
    90,    66,   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,
   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,   116,   nil,
   nil,   nil,   nil,   nil,   nil,   116 ]

racc_goto_check = [
     9,    18,    26,     5,    13,    25,    17,    12,     8,    20,
    10,    30,     1,    32,     2,     3,    24,    17,    27,     4,
    20,     6,    30,     9,    32,     8,    24,     7,    27,    15,
    19,    22,    23,   nil,   nil,     9,    26,    25,    12,   nil,
   nil,   nil,   nil,   nil,   nil,   nil,   nil,    25,    25,    18,
     5,    13,    10,   nil,   nil,    25,    26,   nil,   nil,   nil,
    18,     5,   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,
   nil,   nil,   nil,   nil,   nil,   nil,   nil,   nil,     9,   nil,
   nil,   nil,   nil,   nil,   nil,     9 ]

racc_goto_pointer = [
   nil,    12,    13,    14,    18,     2,    20,    18,    -1,   -27,
     1,   nil,    -4,    -7,   nil,   -15,   nil,   -42,     0,    29,
   -39,   nil,   -31,   -62,   -78,   -57,   -60,   -76,   nil,   nil,
   -37,   nil,   -35 ]

racc_goto_default = [
   nil,   nil,   nil,   nil,   nil,   101,   nil,   nil,   nil,   108,
   nil,    11,   nil,   nil,    44,   nil,    45,   nil,    47,   nil,
   100,    62,   nil,   nil,   nil,   nil,   117,   nil,    64,    99,
   102,    68,   103 ]

racc_reduce_table = [
  0, 0, :racc_error,
  0, 24, :_reduce_none,
  2, 24, :_reduce_none,
  2, 24, :_reduce_none,
  1, 25, :_reduce_none,
  1, 25, :_reduce_none,
  1, 25, :_reduce_none,
  1, 25, :_reduce_none,
  4, 26, :_reduce_none,
  4, 26, :_reduce_none,
  3, 26, :_reduce_none,
  3, 26, :_reduce_none,
  2, 29, :_reduce_12,
  1, 29, :_reduce_13,
  2, 31, :_reduce_14,
  1, 31, :_reduce_15,
  3, 30, :_reduce_16,
  3, 30, :_reduce_17,
  1, 30, :_reduce_18,
  1, 30, :_reduce_19,
  1, 33, :_reduce_none,
  1, 33, :_reduce_21,
  1, 33, :_reduce_none,
  1, 33, :_reduce_none,
  1, 33, :_reduce_none,
  1, 33, :_reduce_none,
  1, 33, :_reduce_none,
  1, 33, :_reduce_27,
  1, 33, :_reduce_28,
  2, 28, :_reduce_none,
  3, 28, :_reduce_none,
  1, 34, :_reduce_31,
  1, 35, :_reduce_32,
  1, 36, :_reduce_none,
  2, 36, :_reduce_none,
  2, 38, :_reduce_none,
  3, 37, :_reduce_36,
  3, 39, :_reduce_37,
  3, 39, :_reduce_38,
  1, 39, :_reduce_39,
  1, 39, :_reduce_40,
  4, 27, :_reduce_41,
  4, 27, :_reduce_42,
  3, 42, :_reduce_43,
  3, 42, :_reduce_44,
  1, 42, :_reduce_45,
  1, 42, :_reduce_46,
  1, 41, :_reduce_none,
  1, 41, :_reduce_48,
  1, 41, :_reduce_none,
  1, 41, :_reduce_none,
  1, 41, :_reduce_none,
  1, 41, :_reduce_none,
  1, 41, :_reduce_none,
  1, 41, :_reduce_54,
  1, 41, :_reduce_55,
  5, 43, :_reduce_none,
  4, 43, :_reduce_none,
  4, 43, :_reduce_none,
  3, 43, :_reduce_none,
  2, 43, :_reduce_none,
  2, 45, :_reduce_none,
  1, 45, :_reduce_none,
  2, 46, :_reduce_none,
  1, 46, :_reduce_none,
  3, 50, :_reduce_none,
  2, 50, :_reduce_none,
  1, 44, :_reduce_67,
  2, 48, :_reduce_68,
  1, 48, :_reduce_69,
  2, 47, :_reduce_none,
  1, 47, :_reduce_none,
  2, 32, :_reduce_none,
  1, 32, :_reduce_none,
  1, 40, :_reduce_74,
  1, 40, :_reduce_none,
  1, 40, :_reduce_none,
  1, 49, :_reduce_77,
  1, 49, :_reduce_none,
  1, 49, :_reduce_none,
  1, 51, :_reduce_none,
  1, 51, :_reduce_none,
  1, 52, :_reduce_none,
  1, 52, :_reduce_none,
  0, 54, :_reduce_none,
  1, 54, :_reduce_none,
  1, 55, :_reduce_86,
  1, 55, :_reduce_87,
  1, 55, :_reduce_88,
  1, 55, :_reduce_89,
  1, 55, :_reduce_90,
  1, 55, :_reduce_91,
  1, 55, :_reduce_92,
  1, 53, :_reduce_93,
  1, 53, :_reduce_94,
  1, 53, :_reduce_95,
  1, 53, :_reduce_96 ]

racc_reduce_n = 97

racc_shift_n = 121

racc_token_table = {
  false => 0,
  :error => 1,
  :IDENTIFIER => 2,
  :STRING_MULTI => 3,
  :STRING_BASIC => 4,
  :STRING_LITERAL_MULTI => 5,
  :STRING_LITERAL => 6,
  :DATETIME => 7,
  :LOCAL_TIME => 8,
  :INTEGER => 9,
  :NON_DEC_INTEGER => 10,
  :FLOAT => 11,
  :FLOAT_KEYWORD => 12,
  :BOOLEAN => 13,
  :NEWLINE => 14,
  :EOS => 15,
  "[" => 16,
  "]" => 17,
  "." => 18,
  "{" => 19,
  "}" => 20,
  "," => 21,
  "=" => 22 }

racc_nt_base = 23

racc_use_result_var = true

Racc_arg = [
  racc_action_table,
  racc_action_check,
  racc_action_default,
  racc_action_pointer,
  racc_goto_table,
  racc_goto_check,
  racc_goto_default,
  racc_goto_pointer,
  racc_nt_base,
  racc_reduce_table,
  racc_token_table,
  racc_shift_n,
  racc_reduce_n,
  racc_use_result_var ]
Ractor.make_shareable(Racc_arg) if defined?(Ractor)

Racc_token_to_s_table = [
  "$end",
  "error",
  "IDENTIFIER",
  "STRING_MULTI",
  "STRING_BASIC",
  "STRING_LITERAL_MULTI",
  "STRING_LITERAL",
  "DATETIME",
  "LOCAL_TIME",
  "INTEGER",
  "NON_DEC_INTEGER",
  "FLOAT",
  "FLOAT_KEYWORD",
  "BOOLEAN",
  "NEWLINE",
  "EOS",
  "\"[\"",
  "\"]\"",
  "\".\"",
  "\"{\"",
  "\"}\"",
  "\",\"",
  "\"=\"",
  "$start",
  "expressions",
  "expression",
  "table",
  "assignment",
  "inline_table",
  "table_start",
  "table_identifier",
  "table_end",
  "newlines",
  "table_identifier_component",
  "inline_table_start",
  "inline_table_end",
  "inline_continued",
  "inline_assignment",
  "inline_next",
  "inline_assignment_key",
  "value",
  "assignment_key_component",
  "assignment_key",
  "array",
  "start_array",
  "array_first_value",
  "array_values",
  "comma",
  "end_array",
  "non_nil_value",
  "array_value",
  "scalar",
  "non_nil_scalar",
  "string",
  "literal",
  "non_nil_literal" ]
Ractor.make_shareable(Racc_token_to_s_table) if defined?(Ractor)

Racc_debug_parser = false

##### State transition tables end #####

# reduce 0 omitted

# reduce 1 omitted

# reduce 2 omitted

# reduce 3 omitted

# reduce 4 omitted

# reduce 5 omitted

# reduce 6 omitted

# reduce 7 omitted

# reduce 8 omitted

# reduce 9 omitted

# reduce 10 omitted

# reduce 11 omitted

module_eval(<<'.,.,', 'parser.y', 20)
  def _reduce_12(val, _values, result)
     @handler.start_(:array_of_tables)
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 21)
  def _reduce_13(val, _values, result)
     @handler.start_(:table)
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 25)
  def _reduce_14(val, _values, result)
     array = @handler.end_(:array_of_tables); @handler.set_context(array, is_array_of_tables: true)
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 26)
  def _reduce_15(val, _values, result)
     array = @handler.end_(:table); @handler.set_context(array)
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 29)
  def _reduce_16(val, _values, result)
     @handler.push(val[2])
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 30)
  def _reduce_17(val, _values, result)
     val[2].split('.').each { |k| @handler.push(k) }
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 32)
  def _reduce_18(val, _values, result)
          keys = val[0].split('.')
      @handler.start_(:table)
      keys.each { |key| @handler.push(key) }

    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 36)
  def _reduce_19(val, _values, result)
     @handler.push(val[0])
    result
  end
.,.,

# reduce 20 omitted

module_eval(<<'.,.,', 'parser.y', 40)
  def _reduce_21(val, _values, result)
     result = StringUtils.replace_escaped_chars(val[0])
    result
  end
.,.,

# reduce 22 omitted

# reduce 23 omitted

# reduce 24 omitted

# reduce 25 omitted

# reduce 26 omitted

module_eval(<<'.,.,', 'parser.y', 46)
  def _reduce_27(val, _values, result)
     result = val[0][0]
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 47)
  def _reduce_28(val, _values, result)
     result = val[0][0]
    result
  end
.,.,

# reduce 29 omitted

# reduce 30 omitted

module_eval(<<'.,.,', 'parser.y', 54)
  def _reduce_31(val, _values, result)
     @handler.start_(:inline)
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 58)
  def _reduce_32(val, _values, result)
          array = @handler.end_(:inline)
      @handler.push_inline(array)

    result
  end
.,.,

# reduce 33 omitted

# reduce 34 omitted

# reduce 35 omitted

module_eval(<<'.,.,', 'parser.y', 71)
  def _reduce_36(val, _values, result)
          keys = @handler.end_(:inline_keys)
      @handler.push(keys)

    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 77)
  def _reduce_37(val, _values, result)
          @handler.push(val[2]) 

    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 79)
  def _reduce_38(val, _values, result)
     val[2].split('.').each { |k| @handler.push(k) }
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 81)
  def _reduce_39(val, _values, result)
          keys = val[0].split('.')
      @handler.start_(:inline_keys)
      keys.each { |key| @handler.push(key) }

    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 86)
  def _reduce_40(val, _values, result)
          @handler.start_(:inline_keys) 
      @handler.push(val[0]) 

    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 92)
  def _reduce_41(val, _values, result)
          keys = @handler.end_(:keys)
      value = keys.pop
      @handler.validate_value(value)
      @handler.push(value)
      @handler.assign(keys)

    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 99)
  def _reduce_42(val, _values, result)
          keys = @handler.end_(:keys)
      value = keys.pop
      @handler.validate_value(value)
      @handler.push(value)
      @handler.assign(keys)

    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 107)
  def _reduce_43(val, _values, result)
     @handler.push(val[2])
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 108)
  def _reduce_44(val, _values, result)
     val[2].split('.').each { |k| @handler.push(k) }
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 110)
  def _reduce_45(val, _values, result)
          keys = val[0].split('.')
      @handler.start_(:keys)
      keys.each { |key| @handler.push(key) }

    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 114)
  def _reduce_46(val, _values, result)
     @handler.start_(:keys); @handler.push(val[0])
    result
  end
.,.,

# reduce 47 omitted

module_eval(<<'.,.,', 'parser.y', 118)
  def _reduce_48(val, _values, result)
     result = StringUtils.replace_escaped_chars(val[0])
    result
  end
.,.,

# reduce 49 omitted

# reduce 50 omitted

# reduce 51 omitted

# reduce 52 omitted

# reduce 53 omitted

module_eval(<<'.,.,', 'parser.y', 124)
  def _reduce_54(val, _values, result)
     result = val[0][0]
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 125)
  def _reduce_55(val, _values, result)
     result = val[0][0]
    result
  end
.,.,

# reduce 56 omitted

# reduce 57 omitted

# reduce 58 omitted

# reduce 59 omitted

# reduce 60 omitted

# reduce 61 omitted

# reduce 62 omitted

# reduce 63 omitted

# reduce 64 omitted

# reduce 65 omitted

# reduce 66 omitted

module_eval(<<'.,.,', 'parser.y', 147)
  def _reduce_67(val, _values, result)
     @handler.start_(:array)
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 150)
  def _reduce_68(val, _values, result)
     array = @handler.end_(:array); @handler.push(array.compact)
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 151)
  def _reduce_69(val, _values, result)
     array = @handler.end_(:array); @handler.push(array.compact)
    result
  end
.,.,

# reduce 70 omitted

# reduce 71 omitted

# reduce 72 omitted

# reduce 73 omitted

module_eval(<<'.,.,', 'parser.y', 162)
  def _reduce_74(val, _values, result)
     @handler.push(val[0])
    result
  end
.,.,

# reduce 75 omitted

# reduce 76 omitted

module_eval(<<'.,.,', 'parser.y', 167)
  def _reduce_77(val, _values, result)
     @handler.push(val[0])
    result
  end
.,.,

# reduce 78 omitted

# reduce 79 omitted

# reduce 80 omitted

# reduce 81 omitted

# reduce 82 omitted

# reduce 83 omitted

# reduce 84 omitted

# reduce 85 omitted

module_eval(<<'.,.,', 'parser.y', 183)
  def _reduce_86(val, _values, result)
     result = val[0].to_f
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 185)
  def _reduce_87(val, _values, result)
          v = val[0]
      result = if v.end_with?('nan')
                 Float::NAN
               else
                 (v[0] == '-' ? -1 : 1) * Float::INFINITY
               end

    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 192)
  def _reduce_88(val, _values, result)
     result = val[0].to_i
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 194)
  def _reduce_89(val, _values, result)
          base = case val[0][1]
             when 'x' then 16
             when 'o' then 8
             when 'b' then 2
             end
      result = val[0].to_i(base)

    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 201)
  def _reduce_90(val, _values, result)
     result = val[0] == 'true' ? true : false
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 203)
  def _reduce_91(val, _values, result)
          _str, year, month, day, hour, min, sec, offset = val[0]
      result = if offset.nil?
                 if hour.nil?
                   LocalDate.new(year, month, day)
                 else
                   LocalDateTime.new(year, month, day, hour, min || 0, sec.to_f)
                 end
               else
                 # Patch for 24:00:00 which Ruby parses
                 if hour.to_i == 24 && min.to_i == 0 && sec.to_i == 0
                   hour = (hour.to_i + 1).to_s
                 end

                 time = Time.new(year, month, day, hour || 0, min || 0, sec.to_f, offset)
                 # Should be out of parser.y?
                 raise ArgumentError, "Invalid Offset Date-Time: #{year}-#{month}-#{day}T#{hour}:#{min}:#{sec}#{offset}" unless min.to_i == time.min && hour.to_i == time.hour && day.to_i == time.day && month.to_i == time.month && year.to_i == time.year
                 time
               end

    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 222)
  def _reduce_92(val, _values, result)
     result = LocalTime.new(*val[0][1..-1])
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 225)
  def _reduce_93(val, _values, result)
     result = StringUtils.replace_escaped_chars(StringUtils.multiline_replacements(val[0]))
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 226)
  def _reduce_94(val, _values, result)
     result = StringUtils.replace_escaped_chars(val[0])
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 227)
  def _reduce_95(val, _values, result)
     result = StringUtils.strip_spaces(val[0])
    result
  end
.,.,

module_eval(<<'.,.,', 'parser.y', 228)
  def _reduce_96(val, _values, result)
     result = val[0]
    result
  end
.,.,

def _reduce_none(val, _values, result)
  val[0]
end

  end   # class GeneratedParser
end   # module Tomlrb
